==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ThanosRulerFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ThanosRulerFluentImpl<A extends ThanosRulerFluent<A>> extends BaseFluent<A> implements ThanosRulerFluent<A>{
  public ThanosRulerFluentImpl() {
  }
  public ThanosRulerFluentImpl(ThanosRuler instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ThanosRulerSpecBuilder spec;
  private ThanosRulerStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ThanosRulerFluent.MetadataNested<A> withNewMetadata() {
    return new ThanosRulerFluentImpl.MetadataNestedImpl();
  }
  public ThanosRulerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ThanosRulerFluentImpl.MetadataNestedImpl(item);
  }
  public ThanosRulerFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ThanosRulerFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ThanosRulerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ThanosRulerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ThanosRulerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ThanosRulerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ThanosRulerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ThanosRulerFluent.SpecNested<A> withNewSpec() {
    return new ThanosRulerFluentImpl.SpecNestedImpl();
  }
  public ThanosRulerFluent.SpecNested<A> withNewSpecLike(ThanosRulerSpec item) {
    return new ThanosRulerFluentImpl.SpecNestedImpl(item);
  }
  public ThanosRulerFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ThanosRulerFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ThanosRulerSpecBuilder().build());
  }
  public ThanosRulerFluent.SpecNested<A> editOrNewSpecLike(ThanosRulerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ThanosRulerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ThanosRulerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ThanosRulerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ThanosRulerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Integer availableReplicas,Boolean paused,Integer replicas,Integer unavailableReplicas,Integer updatedReplicas) {
    return (A)withStatus(new ThanosRulerStatus(availableReplicas, paused, replicas, unavailableReplicas, updatedReplicas));
  }
  public ThanosRulerFluent.StatusNested<A> withNewStatus() {
    return new ThanosRulerFluentImpl.StatusNestedImpl();
  }
  public ThanosRulerFluent.StatusNested<A> withNewStatusLike(ThanosRulerStatus item) {
    return new ThanosRulerFluentImpl.StatusNestedImpl(item);
  }
  public ThanosRulerFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ThanosRulerFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ThanosRulerStatusBuilder().build());
  }
  public ThanosRulerFluent.StatusNested<A> editOrNewStatusLike(ThanosRulerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ThanosRulerFluentImpl that = (ThanosRulerFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ThanosRulerFluent.MetadataNested<N>> implements ThanosRulerFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ThanosRulerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ThanosRulerSpecFluentImpl<ThanosRulerFluent.SpecNested<N>> implements ThanosRulerFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ThanosRulerSpec item) {
      this.builder = new ThanosRulerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ThanosRulerSpecBuilder(this);
    }
    ThanosRulerSpecBuilder builder;
    public N and() {
      return (N) ThanosRulerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ThanosRulerStatusFluentImpl<ThanosRulerFluent.StatusNested<N>> implements ThanosRulerFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ThanosRulerStatus item) {
      this.builder = new ThanosRulerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ThanosRulerStatusBuilder(this);
    }
    ThanosRulerStatusBuilder builder;
    public N and() {
      return (N) ThanosRulerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-6.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ThanosRulerFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ThanosRulerFluentImpl<A extends ThanosRulerFluent<A>> extends BaseFluent<A> implements ThanosRulerFluent<A>{
  public ThanosRulerFluentImpl() {
  }
  public ThanosRulerFluentImpl(ThanosRuler instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ThanosRulerSpecBuilder spec;
  private ThanosRulerStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ThanosRulerFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ThanosRulerFluentImpl.MetadataNestedImpl();
  }
  public ThanosRulerFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ThanosRulerFluentImpl.MetadataNestedImpl(item);
  }
  public ThanosRulerFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ThanosRulerFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ThanosRulerFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ThanosRulerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ThanosRulerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ThanosRulerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ThanosRulerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ThanosRulerFluentImpl.SpecNested<A> withNewSpec() {
    return new ThanosRulerFluentImpl.SpecNestedImpl();
  }
  public ThanosRulerFluentImpl.SpecNested<A> withNewSpecLike(ThanosRulerSpec item) {
    return new ThanosRulerFluentImpl.SpecNestedImpl(item);
  }
  public ThanosRulerFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ThanosRulerFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ThanosRulerSpecBuilder().build());
  }
  public ThanosRulerFluentImpl.SpecNested<A> editOrNewSpecLike(ThanosRulerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ThanosRulerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ThanosRulerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ThanosRulerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ThanosRulerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Integer availableReplicas,Boolean paused,Integer replicas,Integer unavailableReplicas,Integer updatedReplicas) {
    return (A)withStatus(new ThanosRulerStatus(availableReplicas, paused, replicas, unavailableReplicas, updatedReplicas));
  }
  public ThanosRulerFluentImpl.StatusNested<A> withNewStatus() {
    return new ThanosRulerFluentImpl.StatusNestedImpl();
  }
  public ThanosRulerFluentImpl.StatusNested<A> withNewStatusLike(ThanosRulerStatus item) {
    return new ThanosRulerFluentImpl.StatusNestedImpl(item);
  }
  public ThanosRulerFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ThanosRulerFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ThanosRulerStatusBuilder().build());
  }
  public ThanosRulerFluentImpl.StatusNested<A> editOrNewStatusLike(ThanosRulerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ThanosRulerFluentImpl that = (ThanosRulerFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ThanosRulerFluentImpl.MetadataNested<N>> implements ThanosRulerFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ThanosRulerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ThanosRulerSpecFluentImpl<ThanosRulerFluentImpl.SpecNested<N>> implements ThanosRulerFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ThanosRulerSpec item) {
      this.builder = new ThanosRulerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ThanosRulerSpecBuilder(this);
    }
    ThanosRulerSpecBuilder builder;
    public N and() {
      return (N) ThanosRulerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ThanosRulerStatusFluentImpl<ThanosRulerFluentImpl.StatusNested<N>> implements ThanosRulerFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ThanosRulerStatus item) {
      this.builder = new ThanosRulerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ThanosRulerStatusBuilder(this);
    }
    ThanosRulerStatusBuilder builder;
    public N and() {
      return (N) ThanosRulerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
